package com.vendor.loader.model.config;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.loader.Log.Log;
import com.vendor.loader.Messages;
import com.vendor.loader.model.CommonAdapter;
import com.vendor.loader.model.PartitionItem;
import com.vendor.loader.struct.UpgradeFileInfo;
import com.vendor.loader.struct.ssu.SsuUpgradeInfo;
import com.vendor.loader.util.ConvertUtils;
import com.vendor.loader.util.FileUtil;
import com.vendor.loader.util.InvalidDataFormatException;
import com.vendor.loader.util.PropertiesUtility;
import com.vendor.loader.util.StringUtil;
import com.vendor.loader.util.ssu.SsuIniFileParser;
import com.vendor.loader.util.ssu.SsuPackageOptions;
import java.io.File;
import java.io.IOException;
import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import org.dom4j.DocumentException;
import org.eclipse.osgi.util.NLS;

public class SSUConfig extends PropertiesUtility {
  public static final String UPGRADE_MODE_MIN = "0";
  
  public static final String UPGRADE_MODE_MAX = "2";
  
  public static final String SYMBOL_RATE_MIN = "1000";
  
  public static final String SYMBOL_RATE_MAX = "99999";
  
  public static final String TRANSFER_MODE_MIN = "0";
  
  public static final String TRANSFER_MODE_MAX = "1";
  
  public static final String CABLE_MODULATION_MODE_MIN = "0";
  
  public static final String CABLE_MODULATION_MODE_MAX = "5";
  
  public static final String CABLE_FREQUENCY_MODE_MIN = "1";
  
  public static final String CABLE_FREQUENCY_MODE_MAX = "9999";
  
  public static final String BANDWIDTH_MIN = "0";
  
  public static final String BANDWIDTH_MAX = "2";
  
  public static final String CENTER_FREQUENCY_MIN = "10";
  
  public static final String CENTER_FREQUENCY_MAX = "42949672950";
  
  public static final String CONSTELLATION_MIN = "0";
  
  public static final String CONSTELLATION_MAX = "2";
  
  private String chipName;
  
  private ArrayList<UpgradeFileInfo> updateFiles;
  
  private SsuUpgradeInfo ssuUpgradeInfo;
  
  private SsuPackageOptions ssuPackageOptions;
  
  private boolean loadResult = false;
  
  public SSUConfig(String configPath) {
    this.loadResult = loadSSUConfig(configPath);
  }
  
  public String getChipName() {
    return this.chipName;
  }
  
  public void setChipName(String chipName) {
    this.chipName = chipName;
  }
  
  public boolean isLoadResult() {
    return this.loadResult;
  }
  
  public void setLoadResult(boolean loadResult) {
    this.loadResult = loadResult;
  }
  
  public ArrayList<UpgradeFileInfo> getUpdateFiles() {
    return this.updateFiles;
  }
  
  public void setUpdateFiles(ArrayList<UpgradeFileInfo> updateFiles) {
    this.updateFiles = updateFiles;
  }
  
  public SsuUpgradeInfo getSsuUpgradeInfo() {
    return this.ssuUpgradeInfo;
  }
  
  public void setSsuUpgradeInfo(SsuUpgradeInfo ssuUpgradeInfo) {
    this.ssuUpgradeInfo = ssuUpgradeInfo;
  }
  
  public SsuPackageOptions getSsuPackageOptions() {
    return this.ssuPackageOptions;
  }
  
  public void setSsuPackageOptions(SsuPackageOptions ssuPackageOptions) {
    this.ssuPackageOptions = ssuPackageOptions;
  }
  
  private boolean loadSSUConfig(String path) {
    String configName = (new File(path)).getName();
    if (!FileUtil.isExists(path)) {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_FILE_PATH_DONT_EXIST, configName));
      return false;
    } 
    ArrayList<String> definitionLines = FileUtil.readAllLines(path);
    if (definitionLines == null) {
      Log.errorln(NLS.bind("Failed to read the file, the file path is as follows: ", path));
      return false;
    } 
    initProperties(definitionLines);
    if (!initParameter())
      return false; 
    if (!loadUpgrateInfo())
      return false; 
    if (this.updateFiles != null && this.ssuPackageOptions != null)
      this.ssuPackageOptions.setNumberUpgradeFile(this.updateFiles.size()); 
    this.loadResult = true;
    Log.println(NLS.bind(Messages.MESSAGE_LOAD_FILE_SUCCESS, configName));
    return true;
  }
  
  private void initProperties(ArrayList<String> definitionLines) {
    for (String s : definitionLines) {
      String line = s.trim().replace("\t", "");
      if (line.startsWith("["))
        continue; 
      if (line.contains("=")) {
        String[] ppt = line.split("=");
        if (ppt.length > 1)
          set(ppt[0], ppt[1]); 
      } 
    } 
  }
  
  private boolean initParameter() {
    String chipNameStr = queryForString("ChipName");
    if (chipNameStr != null && !chipNameStr.isEmpty()) {
      String upperCaseChipName = CommonAdapter.convertChipName(chipNameStr);
      setChipName(upperCaseChipName);
    } else {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "ChipName"));
      return false;
    } 
    String pathStr = queryForString("Path");
    if (pathStr != null && !pathStr.isEmpty()) {
      if (!loadXmlOrIni(pathStr))
        return false; 
    } else {
      Log.errorln(NLS.bind(Messages.MESSAGE_ERROR_PARAMETER_DONT_FIND, "Path"));
      return false;
    } 
    return true;
  }
  
  private boolean loadXmlOrIni(String pathStr) {
    if (pathStr.toUpperCase().endsWith("INI")) {
      try {
        SsuIniFileParser parser = new SsuIniFileParser(pathStr);
        this.updateFiles = parser.getUpgradFiles();
        return true;
      } catch (InvalidDataFormatException e) {
        Log.errorln(e.getMessage());
      } catch (Exception e) {
        Log.errorln(Messages.LoaderComposite_86);
      } 
    } else {
      if (pathStr.toUpperCase().endsWith("XML")) {
        List<PartitionItem> partitionList = null;
        try {
          partitionList = PartitionItem.load(new File(pathStr), true);
          if (partitionList == null || partitionList.isEmpty()) {
            Log.errorln(NLS.bind(Messages.XMLINVALID, pathStr));
            return false;
          } 
          SsuIniFileParser parser = new SsuIniFileParser(partitionList);
          this.updateFiles = parser.getUpgradFiles();
          return true;
        } catch (DocumentException documentException) {
        
        } catch (IOException iOException) {
        
        } catch (InvalidDataFormatException invalidDataFormatException) {}
        Log.errorln(NLS.bind(Messages.XMLINVALID, pathStr));
        return false;
      } 
      Log.errorln(NLS.bind(Messages.MESSAGE_PARTITION_LOAD_FAILED, pathStr));
      return false;
    } 
    return true;
  }
  
  private boolean loadUpgrateInfo() {
    if (!checkSsuUpgradeInfo())
      return false; 
    loadSsuUpgradeInfo();
    if (!checkSsuPackageOptions())
      return false; 
    loadSsuPackageOptions();
    return true;
  }
  
  private void loadSsuPackageOptions() {
    this.ssuPackageOptions = new SsuPackageOptions();
    setInsertLinkDesParamValue(this.ssuPackageOptions);
    setInsertEmptyPacketParamValue(this.ssuPackageOptions);
  }
  
  private void setInsertEmptyPacketParamValue(SsuPackageOptions ssuPackageOptions) {
    boolean insertEmptyPacket = ConvertUtils.stringToBoolean(queryForString("InsertEmptyPacket"));
    ssuPackageOptions.setInsertEmptyPacket(insertEmptyPacket);
    if (insertEmptyPacket) {
      ssuPackageOptions
        .setSymbolRate(queryForInteger("SymbolRateOfUpgradeStreamForEmpty").intValue());
      ssuPackageOptions
        .setValidSymbolRate(queryForInteger("SymbolRateOfVaildData").intValue());
    } 
  }
  
  private void setInsertLinkDesParamValue(SsuPackageOptions ssuPackageOptions) {
    boolean insertLinkDes = ConvertUtils.stringToBoolean(queryForString("InsertLinkDescriptor"));
    ssuPackageOptions.setInsertLinkedDescriptorBtn(insertLinkDes);
    if (insertLinkDes) {
      ssuPackageOptions
        .setUpgradeTypeCombo(queryForInteger("UpgradeMode").intValue());
      ssuPackageOptions
        .setSymbolRate(queryForInteger("SymbolRateOfUpgradeStream").intValue());
      Integer transferMode = queryForInteger("TransferMode");
      if (transferMode == null)
        return; 
      ssuPackageOptions.setTransferModeCombo(transferMode.intValue());
      if (transferMode.intValue() == TransferMode.Cable.ordinal()) {
        ssuPackageOptions
          .setCableModulation(queryForInteger("CableModulationMode").intValue());
        Double doubleValue = Double.valueOf(queryForDouble("CableFrequency"));
        if (doubleValue != null)
          ssuPackageOptions.setCableFrequency(doubleValue.doubleValue()); 
      } 
      if (transferMode.intValue() == TransferMode.Terrestrial.ordinal()) {
        ssuPackageOptions.setBandWidth(queryForInteger("BandWidth").intValue());
        ssuPackageOptions
          .setCentreFrequency(queryForLong("CenterFrequency").longValue());
        ssuPackageOptions
          .setConstellation(queryForInteger("Constellation").intValue());
      } 
    } 
  }
  
  private void loadSsuUpgradeInfo() {
    this.ssuUpgradeInfo = new SsuUpgradeInfo();
    this.ssuUpgradeInfo.setDownloadGroupId(queryForInteger("GroupID").intValue());
    this.ssuUpgradeInfo.setDownloadPid(queryForInteger("PID").intValue());
    this.ssuUpgradeInfo.setManufacturerId(queryForInteger("ManufacturerID").intValue());
    this.ssuUpgradeInfo.setHardwareVersion(queryForInteger("HardwareVersion").intValue());
    this.ssuUpgradeInfo.setSoftwareVersion(queryForInteger("SoftwareVersion").intValue());
    this.ssuUpgradeInfo.setStartSn(queryForInteger("StartSequenceNumber").intValue());
    this.ssuUpgradeInfo.setEndSn(queryForInteger("EndSequenceNumber").intValue());
  }
  
  private boolean checkSsuUpgradeInfo() {
    if (!checkParamValue("GroupID", "0x2", "0xFFFF"))
      return false; 
    if (!checkParamValue("PID", "0x20", "0x1FFE"))
      return false; 
    if (!checkParamValue("ManufacturerID", "0x0000", "0xFFFF"))
      return false; 
    if (!checkParamValue("HardwareVersion", "0x00", "0xFFFFFFFF"))
      return false; 
    if (!checkParamValue("SoftwareVersion", "0x00000000", "0xFFFFFFFF"))
      return false; 
    if (!checkParamValue("StartSequenceNumber", "0x00000000", "0xFFFFFFFF"))
      return false; 
    if (!checkParamValue("EndSequenceNumber", "0x00000000", "0xFFFFFFFF"))
      return false; 
    try {
      BigInteger sn = StringUtil.toBigInteger(queryForString("StartSequenceNumber"));
      BigInteger en = StringUtil.toBigInteger(queryForString("EndSequenceNumber"));
      if (sn.compareTo(en) >= 0) {
        Log.showError(Messages.UpgradeInfoGroup_StartSnAndEndSnInputError);
        return false;
      } 
    } catch (NumberFormatException e) {
      Log.showError(Messages.UpgradeInfoGroup_InputInvalid);
      return false;
    } 
    return true;
  }
  
  private boolean checkSsuPackageOptions() {
    if (!checkBooleanParam(queryForString("InsertLinkDescriptor"), "InsertLinkDescriptor"))
      return false; 
    if (ConvertUtils.stringToBoolean(queryForString("InsertLinkDescriptor")) && 
      !checkInsertLinkDescOptions())
      return false; 
    if (!checkBooleanParam(queryForString("InsertEmptyPacket"), "InsertEmptyPacket"))
      return false; 
    if (ConvertUtils.stringToBoolean(queryForString("InsertEmptyPacket")) && 
      !checkInsertEmptyPacketOptions())
      return false; 
    return true;
  }
  
  private boolean checkBooleanParam(String insertLinkDesStr, String paramName) {
    boolean result = (insertLinkDesStr != null && (insertLinkDesStr.equalsIgnoreCase("true") || insertLinkDesStr.equalsIgnoreCase("false")));
    if (!result)
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_Invalid, paramName)); 
    return result;
  }
  
  private boolean checkInsertEmptyPacketOptions() {
    if (!checkParamValue("SymbolRateOfUpgradeStreamForEmpty", "1000", "99999"))
      return false; 
    if (!checkParamValue("SymbolRateOfVaildData", "1000", "99999"))
      return false; 
    int symbolRate = queryForInteger("SymbolRateOfUpgradeStreamForEmpty").intValue();
    int validSymbolRate = queryForInteger("SymbolRateOfVaildData").intValue();
    if (symbolRate == validSymbolRate || validSymbolRate > symbolRate) {
      Log.println(NLS.bind(Messages.FileSize_Error, new Object[] { "SymbolRateOfUpgradeStreamForEmpty", "SymbolRateOfVaildData" }));
      return false;
    } 
    return true;
  }
  
  private boolean checkInsertLinkDescOptions() {
    if (!checkParamValue("UpgradeMode", "0", "2"))
      return false; 
    if (!checkParamValue("SymbolRateOfUpgradeStream", "1000", "99999"))
      return false; 
    if (!checkParamValue("TransferMode", "0", "1"))
      return false; 
    Integer transferMode = queryForInteger("TransferMode");
    if (transferMode.intValue() == TransferMode.Cable.ordinal() && 
      !checkModulationModeAndFrequency())
      return false; 
    if (transferMode.intValue() == TransferMode.Terrestrial.ordinal()) {
      if (!checkParamValue("BandWidth", "0", "2"))
        return false; 
      if (!checkParamValue("CenterFrequency", "10", "42949672950"))
        return false; 
      if (!checkParamValue("Constellation", "0", "2"))
        return false; 
    } 
    return true;
  }
  
  private boolean checkModulationModeAndFrequency() {
    if (!checkParamValue("CableModulationMode", "0", "5"))
      return false; 
    String cableFrequencyStr = queryForString("CableFrequency");
    try {
      double cableFrequency = Double.parseDouble(cableFrequencyStr);
      if (cableFrequency < 
        Double.parseDouble("1")) {
        Log.errorln(NLS.bind(Messages.FileSize_Minimum, "CableFrequency", 
              
              Double.valueOf(Double.parseDouble("1"))));
        return false;
      } 
      if (cableFrequency > 
        Double.parseDouble("9999")) {
        Log.errorln(NLS.bind(Messages.FileSize_Maximum, "CableFrequency", 
              
              Double.valueOf(Double.parseDouble("9999"))));
        return false;
      } 
      int fractionalBits = 4;
      if (cableFrequencyStr.indexOf(".") > 0) {
        String[] result = cableFrequencyStr.split("\\.");
        if (result[1].length() > fractionalBits) {
          Log.errorln(Messages.CableModuValue);
          return false;
        } 
      } 
    } catch (NumberFormatException e) {
      Log.errorln(NLS.bind(Messages.CMD_PARAMETER_Invalid, "CableFrequency"));
      return false;
    } 
    return true;
  }
}
